@@ -1,12 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2002 the Java-Gnome Team, all rights reserved.
- *
- * The Java-Gnome Team Members:
- *   Jean Van Wyk <jeanvanwyk@iname.com>
- *   Jeffrey S. Morgan <jeffrey.morgan@bristolwest.com>
- *   Dan Bornstein <danfuzz@milk.com>
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -14,105 +9,106 @@
 
 #include <jni.h>
 #include <gconf/gconf.h>
+#include <libgtk-java/jg_jnu.h>
 
 #ifndef _Included_org_gnu_gconf_ConfValue
 #define _Included_org_gnu_gconf_ConfValue
 #ifdef __cplusplus
 extern "C" {
 #endif
+
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_new
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1new
+JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1new
   (JNIEnv *env, jclass cls, jint type)
 {
-	return (jint)gconf_value_new((GConfValueType) type);
+	return getHandleFromPointer(env, gconf_value_new((GConfValueType) type));
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_copy
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1copy
-  (JNIEnv *env, jclass cls, jint value)
+JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1copy
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_copy((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return getHandleFromPointer(env, gconf_value_copy(value_g));
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_free
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1free
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	gconf_value_free((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gconf_value_free(value_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_string
- * Signature: (I)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1string
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	gchar* result = (gchar*)gconf_value_get_string((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gchar* result = (gchar*)gconf_value_get_string(value_g);
 	return (*env)->NewStringUTF(env, result);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_int
- * Signature: (I)I
  */
 JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1int
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_get_int((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return (jint)gconf_value_get_int(value_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_float
- * Signature: (I)D
  */
 JNIEXPORT jdouble JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1float
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jdouble)gconf_value_get_float((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return (jdouble)gconf_value_get_float(value_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_list_type
- * Signature: (I)I
  */
 JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1list_1type
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_get_list_type((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return (jint)gconf_value_get_list_type(value_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_list
- * Signature: (I)[Ljava/lang/Object;
  */
 JNIEXPORT jobjectArray JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1list
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	GSList* list = gconf_value_get_list((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	GSList* list = gconf_value_get_list(value_g);
 	int i = 0;
 	jclass aCls = NULL;
 	guint len;
 	jobjectArray ar;
 	len = g_slist_length(list);
-	GConfValueType vt = gconf_value_get_list_type((GConfValue*)value);
+	GConfValueType vt = gconf_value_get_list_type(value_g);
 	if (vt == GCONF_VALUE_STRING)
 		aCls = (*env)->FindClass(env, "java/lang/String");
 	else if (vt == GCONF_VALUE_INT)
@@ -167,146 +163,149 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1l
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_car
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1car
-  (JNIEnv *env, jclass cls, jint value)
+JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1car
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_get_car((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return getHandleFromPointer(env, gconf_value_get_car(value_g));
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_cdr
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1cdr
-  (JNIEnv *env, jclass cls, jint value)
+JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1cdr
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_get_cdr((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return getHandleFromPointer(env, gconf_value_get_cdr(value_g));
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_bool
- * Signature: (I)Z
  */
 JNIEXPORT jboolean JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1bool
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jboolean)gconf_value_get_bool((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return (jboolean)gconf_value_get_bool(value_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_get_schema
- * Signature: (I)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1schema
-  (JNIEnv *env, jclass cls, jint value)
+JNIEXPORT jobject JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1get_1schema
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	return (jint)gconf_value_get_schema((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	return getHandleFromPointer(env, gconf_value_get_schema(value_g));
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_int
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1int
-  (JNIEnv *env, jclass cls, jint value, jint theInt)
+  (JNIEnv *env, jclass cls, jobject value, jint theInt)
 {
-	gconf_value_set_int((GConfValue*)value, (int)theInt);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gconf_value_set_int(value_g, (int)theInt);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_string
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1string
-  (JNIEnv *env, jclass cls, jint value, jstring theString)
+  (JNIEnv *env, jclass cls, jobject value, jstring theString)
 {
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
 	const gchar* str = (*env)->GetStringUTFChars(env, theString, NULL);
-	gconf_value_set_string((GConfValue*)value, str);
+	gconf_value_set_string(value_g, str);
 	(*env)->ReleaseStringUTFChars(env, theString, str);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_bool
- * Signature: (IZ)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1bool
-  (JNIEnv *env, jclass cls, jint value, jboolean theBool)
+  (JNIEnv *env, jclass cls, jobject value, jboolean theBool)
 {
-	gconf_value_set_bool((GConfValue*)value, (gboolean)theBool);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gconf_value_set_bool(value_g, (gboolean)theBool);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_float
- * Signature: (ID)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1float
-  (JNIEnv *env, jclass cls, jint value, jdouble theDouble)
+  (JNIEnv *env, jclass cls, jobject value, jdouble theDouble)
 {
-	gconf_value_set_float((GConfValue*)value, (gdouble)theDouble);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gconf_value_set_float(value_g, (gdouble)theDouble);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_schema
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1schema
-  (JNIEnv *env, jclass cls, jint value, jint schema)
+  (JNIEnv *env, jclass cls, jobject value, jobject schema)
 {
-	gconf_value_set_schema((GConfValue*)value, (GConfSchema*)schema);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	GConfSchema* schema_g = (GConfSchema*)getPointerFromHandle(env, schema);
+	gconf_value_set_schema(value_g, schema_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_car
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1car
-  (JNIEnv *env, jclass cls, jint value, jint car)
+  (JNIEnv *env, jclass cls, jobject value, jobject car)
 {
-	gconf_value_set_car((GConfValue*)value, (GConfValue*)car);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	GConfValue* car_g = (GConfValue*)getPointerFromHandle(env, car);
+	gconf_value_set_car(value_g, car_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_cdr
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1cdr
-  (JNIEnv *env, jclass cls, jint value, jint cdr)
+  (JNIEnv *env, jclass cls, jobject value, jobject cdr)
 {
-	gconf_value_set_cdr((GConfValue*)value, (GConfValue*)cdr);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	GConfValue* cdr_g = (GConfValue*)getPointerFromHandle(env, cdr);
+	gconf_value_set_cdr(value_g, cdr_g);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_list_type
- * Signature: (II)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1list_1type
-  (JNIEnv *env, jclass cls, jint value, jint type)
+  (JNIEnv *env, jclass cls, jobject value, jint type)
 {
-	gconf_value_set_list_type((GConfValue*)value, (GConfValueType)type);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gconf_value_set_list_type(value_g, (GConfValueType)type);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_set_list
- * Signature: (I[Ljava/lang/Object;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1list
-  (JNIEnv *env, jclass cls, jint value, jobjectArray list)
+  (JNIEnv *env, jclass cls, jobject value, jobjectArray list)
 {
-	GConfValueType vt = gconf_value_get_list_type((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	GConfValueType vt = gconf_value_get_list_type(value_g);
 	int i = 0;
 	jclass aCls = NULL;
 	jobject obj;
@@ -321,60 +320,60 @@ JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1set_1list
 	for (i = 0; i < len; i++) {
 		obj = (*env)->GetObjectArrayElement(env, list, i);
 		if (vt == GCONF_VALUE_STRING) {
-			jstring value = (jstring)obj;
-			const gchar* v = (*env)->GetStringUTFChars(env, value, NULL);
+			jstring val = (jstring)obj;
+			const gchar* v = (*env)->GetStringUTFChars(env, val, NULL);
 			data = (gpointer)v;
 		}
 		else if (vt == GCONF_VALUE_INT) {
-			jint value;
+			jint val;
 			aCls = (*env)->FindClass(env, "java/lang/Integer");
 			mid = (*env)->GetMethodID(env, cls, "intValue", "()I");
 			if (NULL == mid)
 				return;
-			value = (*env)->CallIntMethod(env, obj, mid);
-			data = (gpointer)&value;
+			val = (*env)->CallIntMethod(env, obj, mid);
+			data = (gpointer)&val;
 		}
 		else if (vt == GCONF_VALUE_FLOAT) {
-			jdouble value;
+			jdouble val;
 			aCls = (*env)->FindClass(env, "java/lang/Double");
 			mid = (*env)->GetMethodID(env, cls, "doubleValue", "()D");
 			if (NULL == mid)
 				return;
-			value = (*env)->CallDoubleMethod(env, obj, mid);
-			data = (gpointer)&value;
+			val = (*env)->CallDoubleMethod(env, obj, mid);
+			data = (gpointer)&val;
 		}
 		else if (vt == GCONF_VALUE_BOOL) {
-			jboolean value;
+			jboolean val;
 			aCls = (*env)->FindClass(env, "java/lang/Boolean");
 			mid = (*env)->GetMethodID(env, cls, "booleanValue", "()Z");
 			if (NULL == mid)
 				return;
-			value = (*env)->CallBooleanMethod(env, obj, mid);
-			data = (gpointer)&value;
+			val = (*env)->CallBooleanMethod(env, obj, mid);
+			data = (gpointer)&val;
 		}
 		else if (vt == GCONF_VALUE_SCHEMA) {
-			jint value;
+			jobject val;
 			aCls = (*env)->FindClass(env, "org/gnu/gconf/ConfSchema");
 			fid = (*env)->GetFieldID(env, aCls, "handle", "I");
 			if (fid == NULL)
 				return;
-			value = (jint)(*env)->GetObjectField(env, obj, fid);
-			data = (gpointer)value;
+			val = (jobject)(*env)->GetObjectField(env, obj, fid);
+			data = (gpointer)val;
 		}
 		gslist = g_slist_append(gslist, data);
 	}
-	gconf_value_set_list((GConfValue*)value, gslist);
+	gconf_value_set_list(value_g, gslist);
 }
 
 /*
  * Class:     org_gnu_gconf_ConfValue
  * Method:    gconf_value_to_string
- * Signature: (I)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL Java_org_gnu_gconf_ConfValue_gconf_1value_1to_1string
-  (JNIEnv *env, jclass cls, jint value)
+  (JNIEnv *env, jclass cls, jobject value)
 {
-	gchar *str = gconf_value_to_string((GConfValue*)value);
+	GConfValue* value_g = (GConfValue*)getPointerFromHandle(env, value);
+	gchar *str = gconf_value_to_string(value_g);
 	return (*env)->NewStringUTF(env, str);
 }
 
